@@ -38,10 +38,12 @@
 
 define ([
     'target',
-    'app/daction-start'
+    'app/daction-start',
+    'app/emp-lib',
 ], function (
     target,
-    dactionStart
+    dactionStart,
+    empLib,
 ) {
 
     return function () {
@@ -117,17 +119,18 @@ define ([
             'name': 'actionEmplSearch',
             'type': 'daction',
             'menuText': 'Search',
-            'aclProfile': 'admin',
+            'aclProfile': 'inactive',
             'start': dactionStart('actionEmplSearch'),
             'pushable': false
         });
         target.push('masqEmployee', {
             'name': 'masqEmployee',
             'type': 'daction',
-            'menuText': 'Masquerade (begin/end)',
-            'aclProfile': 'admin',
+            'menuText': 'Masquerade',
+            'aclProfile': 'inactive',
             'start': dactionStart('masqEmployee'),
-            'pushable': false
+            'pushable': false,
+            'onlyWhen': empLib.currentEmpHasReports,
         });
         target.push('empProfileSetSuperChoose', {
             'name': 'empProfileSetSuperChoose',
@@ -295,7 +298,7 @@ define ([
         target.push('createSingleIntMenuItem', {
             'name': 'createSingleIntMenuItem',
             'type': 'daction',
-            'menuText': 'Create single interval',
+            'menuText': 'Create single',
             'aclProfile': 'active',
             'start': dactionStart('createSingleIntMenuItem'),
             'pushable': false
@@ -308,6 +311,14 @@ define ([
             'start': dactionStart('createSingleIntSave'),
             'pushable': false
         });
+        target.push('createLockSave', {
+            'name': 'createLockSave',
+            'type': 'daction',
+            'menuText': 'Save',
+            'aclProfile': 'active',
+            'start': dactionStart('createLockSave'),
+            'pushable': false
+        });
         target.push('deleteSingleInt', {
             'name': 'deleteSingleInt',
             'type': 'daction',
@@ -316,6 +327,14 @@ define ([
             'start': dactionStart('deleteSingleInt'),
             'pushable': false
         });
+        target.push('deleteLock', {
+            'name': 'deleteLock',
+            'type': 'daction',
+            'menuText': 'Delete',
+            'aclProfile': 'active',
+            'start': dactionStart('deleteLock'),
+            'pushable': false
+        });
         target.push('updateSingleIntSave', {
             'name': 'updateSingleIntSave',
             'type': 'daction',
@@ -332,6 +351,14 @@ define ([
             'start': dactionStart('viewIntervalsAction'),
             'pushable': true
         });
+        target.push('viewLocksAction', {
+            'name': 'viewLocksAction',
+            'type': 'daction',
+            'menuText': 'View',
+            'aclProfile': 'active',
+            'start': dactionStart('viewLocksAction'),
+            'pushable': true
+        });
 
         // Activity actions - select
         target.push('selectActivityAction', {
