@@ -102,7 +102,7 @@ define ([
         target.push('createMultipleInt', {
             'name': 'createMultipleInt',
             'type': 'dform',
-            'menuText': 'Create multiple intervals',
+            'menuText': 'Create multiple',
             'title': 'Create multiple intervals according to schedule',
             'preamble': "Hints: (1) TAB or ENTER to validate and advance to next field " +
                         "(2) enter month by name (e.g. \"June\") or number (e.g. \"6\"); " +
@@ -186,6 +186,20 @@ define ([
             }
         }); // createSingleInt
 
+        target.push('createLock', {
+            'name': 'createLock',
+            'type': 'dform',
+            'menuText': 'Create',
+            'title': 'Create a Lock',
+            'preamble': "Hints: (1) TAB or ENTER to validate and advance to next field ",
+            'aclProfile': 'active',
+            'entriesWrite': [entries.iNyear, entries.iNmonth,],
+            'rememberState': true,
+            'miniMenu': {
+                entries: ['createLockSave']
+            }
+        }); // createLock
+
         target.push('createSingleIntFixedDay', {
             'name': 'createSingleIntFixedDay',
             'type': 'dform',
@@ -340,9 +354,6 @@ define ([
             'type': 'dform',
             'menuText': 'REST server',
             'title': 'REST server details',
-            'preamble': '<b>URI</b> used by this App::Dochazka::WWW instance to communicate ' +
-                        'with REST server;<br><b>version</b> of App::Dochazka::REST running ' +
-                        'on REST server',
             'aclProfile': 'admin',
             'entriesRead': [entries.rSDurl, entries.rSDversion],
             'miniMenu': {
@@ -495,7 +506,7 @@ define ([
         target.push('viewIntervalsPrep', {
             'name': 'viewIntervalsPrep',
             'type': 'dform',
-            'menuText': 'View intervals',
+            'menuText': 'View',
             'title': 'View intervals for date or range of dates',
             'preamble': "Hints: (1) TAB or ENTER to validate and advance to next field " +
                         "(2) enter month by name (e.g. \"June\") or number (e.g. \"6\"); " +
@@ -519,6 +530,24 @@ define ([
             }
         }); // viewIntervalsPrep
 
+        target.push('viewLocksPrep', {
+            'name': 'viewLocksPrep',
+            'type': 'dform',
+            'menuText': 'View',
+            'title': 'View locks',
+            'preamble': "Hints: (1) TAB or ENTER to validate and advance to next field " +
+                        "(2) enter month by name (e.g. \"June\") or number (e.g. \"6\"); " +
+                        "DEFAULT: current month ",
+            'aclProfile': 'inactive',
+            'entriesWrite': [
+                entries.iNyear,
+            ],
+            'rememberState': true,
+            'miniMenu': {
+                entries: ['viewLocksAction']
+            }
+        }); // viewLocksPrep
+
     }; // return function ()
     
 });
