@@ -47,16 +47,16 @@ define ([
         target.push('mainAdmin', {
             'name': 'mainAdmin',
             'type': 'dmenu',
-            'menuText': 'Adminitrivia',
-            'title': 'Adminitrivia menu',
+            'menuText': 'Admin',
+            'title': 'Admin menu',
             'aclProfile': 'admin',
-            'entries': ['restServerDetailsAction']
+            'entries': ['ldapLookup', 'searchEmployee', 'restServerDetailsAction']
         });
 
         target.push('mainEmpl', {
             'name': 'mainEmpl',
             'type': 'dmenu',
-            'menuText': 'Employee',
+            'menuText': 'Profile',
             'title': 'Employee menu',
             'aclProfile': 'passerby',
             'entries': ['myProfileAction', 'ldapLookup', 'searchEmployee',]
@@ -65,26 +65,35 @@ define ([
         target.push('mainInt', {
             'name': 'mainInt',
             'type': 'dmenu',
-            'menuText': 'Interval',
+            'menuText': 'Intervals',
             'title': 'Interval menu',
             'aclProfile': 'passerby',
             'entries': ['viewIntervalsPrep', 'createSingleIntMenuItem', 'createMultipleInt',],
         });
 
+        target.push('mainLock', {
+            'name': 'mainLock',
+            'type': 'dmenu',
+            'menuText': 'Locks',
+            'title': 'Lock menu',
+            'aclProfile': 'passerby',
+            'entries': ['viewLocksPrep', 'createLock',],
+        });
+
         target.push('mainMenu', {
             'name': 'mainMenu',
             'type': 'dmenu',
             'menuText': 'Main',
             'title': 'Main menu',
             'aclProfile': 'passerby',
-            'entries': ['mainEmpl', 'mainInt', 'mainSched', 'masqEmployee',
+            'entries': ['myProfileAction', 'mainInt', 'mainLock', 'mainSched', 'masqEmployee',
                         'mainAdmin']
         });
 
         target.push('mainSched', {
             'name': 'mainSched',
             'type': 'dmenu',
-            'menuText': 'Schedule',
+            'menuText': 'Schedules',
             'title': 'Schedule menu',
             'aclProfile': 'admin',
             'entries': ['schedLookup',
