@@ -114,6 +114,25 @@ define ([
             ajax(rest, sc, fc);
         },
 
+        currentEmpHasReports = function () {
+            var cu = currentUser('obj'),
+                cup = appCaches.getProfileByEID(cu.eid),
+                priv = currentUser('priv');
+            console.log("Entering currentEmpHasReports(), current employee profile", cup);
+            if (priv === 'admin') {
+                // not applicable to admins
+                return true;
+            }
+            if (typeof cup !== 'object' || ! 'hasReports' in cup || typeof cup.hasReports !== 'function') {
+                throw "Profile of current user has not been loaded into the cache";
+            }
+            if (typeof cup.hasReports === 'function') {
+                return cup.hasReports();
+            }
+            console.log("CRITICAL ERROR: Bad current user profile object", cup);
+            throw "Bad current user profile object";
+        },
+
         empProfileEditSave = function (emp) {
                 // protoEmp = Object.create(prototypes.empProfile),
             var empObj,
@@ -164,7 +183,7 @@ define ([
                                     coreLib.dbrowserState.set[coreLib.dbrowserState.pos]);
                         $.extend(
                             coreLib.dbrowserState.set[coreLib.dbrowserState.pos],
-                            employeeProfile
+                            empObj,
                         );
                         stack.pop(undefined, {"resultLine": "Employee profile updated"});
                     } else {
@@ -277,12 +296,13 @@ define ([
             obj['email'] = profileObj.emp.email;
             obj['remark'] = profileObj.emp.remark;
             obj['sec_id'] = profileObj.emp.sec_id;
-            obj['has_reports'] = ( profileObj.has_reports === 0 ) ? null : profileObj.has_reports;
+            obj['has_reports'] = ( profileObj.has_reports === 0 || profileObj.has_reports === undefined ) ? null : profileObj.has_reports;
             stack.push('empProfile', obj, newOpts);
         };
 
     return {
         actionEmplSearch: actionEmplSearch,
+        currentEmpHasReports: currentEmpHasReports,
         empProfileEditSave: empProfileEditSave,
         empProfileSetSuperChoose: empProfileSetSuperChoose,
         empProfileSetSuperCommit: empProfileSetSuperCommit,
