@@ -42,12 +42,14 @@ define ([
     'app/int-lib',
     'datetime',
 ], function (
-    caches,
+    appCaches,
     actLib,
     intLib,
     datetime,
 ) {
 
+    console.log("appCaches", appCaches);
+
     return {
 
         acTaid: {
@@ -58,7 +60,7 @@ define ([
             prop: 'aid',
             hidden: true,
             maxlen: 6,
-            populate: caches.populateAIDfromCode,
+            populate: appCaches.populateAIDfromCode,
         },
         acTcode: {
             name: 'acTcode',
@@ -115,7 +117,6 @@ define ([
             text: 'Status',
             prop: 'priv',
             maxlen: 10,
-            // populate: empLib.populateProfilePriv,
         },
         ePprivEffective: {
             name: 'ePprivEffective',
@@ -124,7 +125,6 @@ define ([
             text: 'Status since',
             prop: 'privEffective',
             maxlen: 30,
-            // populate: empLib.populateProfilePrivEffective,
         },
         ePremark: {
             name: 'ePremark',
@@ -207,7 +207,7 @@ define ([
             text: 'Supervisor',
             prop: 'ePsuperNick',
             maxlen: 30,
-            populate: caches.populateSupervisorNick,
+            populate: appCaches.populateSupervisorNick,
         },
         ePhasReports: {
             name: 'ePhasReports',
@@ -322,7 +322,7 @@ define ([
             text: 'Existing',
             prop: 'iNexistintvls',
             maxlen: 50,
-            populate: caches.populateExistingIntervals,
+            populate: appCaches.populateExistingIntervals,
         },
         iNiid: {
             name: 'iNiid',
@@ -330,7 +330,7 @@ define ([
             aclProfileWrite: 'admin',
             text: 'IID',
             prop: 'iid',
-            maxlen: 8,
+            maxlen: 10,
         },
         iNlastexistintvl: {
             name: 'iNlastexistintvl',
@@ -339,7 +339,7 @@ define ([
             text: 'Last existing',
             prop: 'iNlastexistintvl',
             maxlen: 50,
-            populate: caches.populateLastExisting,
+            populate: appCaches.populateLastExisting,
         },
         iNlastplusoffset: {
             name: 'iNlastplusoffset',
@@ -348,7 +348,7 @@ define ([
             text: 'Time range',
             prop: 'iNlastplusoffset',
             maxlen: 50,
-            populate: caches.populateLastPlusOffset,
+            populate: appCaches.populateLastPlusOffset,
         },
         iNmonth: {
             name: 'iNmonth',
@@ -366,7 +366,7 @@ define ([
             text: 'To be created',
             prop: 'iNnextscheduled',
             maxlen: 50,
-            populate: caches.populateNextScheduled,
+            populate: appCaches.populateNextScheduled,
         },
         iNoffset: {
             name: 'iNoffset',
@@ -383,7 +383,7 @@ define ([
             text: 'Scheduled',
             prop: 'iNschedintvls',
             maxlen: 50,
-            populate: caches.populateSchedIntvlsForDate,
+            populate: appCaches.populateSchedIntvlsForDate,
         },
         iNsid: {
             name: 'iNsid',
@@ -393,7 +393,7 @@ define ([
             prop: 'iNsid',
             hidden: true,
             maxlen: 20,
-            populate: caches.populateSIDByDate,
+            populate: appCaches.populateSIDByDate,
         },
         iNtimerange: {
             name: 'iNtimerange',
@@ -434,7 +434,23 @@ define ([
             prop: 'iNyear',
             hidden: true,
             maxlen: 5,
-            populate: caches.populateYear,
+            populate: appCaches.populateYear,
+        },
+        lOintvl: {
+            name: 'lOintvl',
+            aclProfileRead: 'inactive',
+            aclProfileWrite: 'active',
+            text: 'Interval',
+            prop: 'intvl',
+            maxlen: 40,
+        },
+        lOlid: {
+            name: 'lOlid',
+            aclProfileRead: 'inactive',
+            aclProfileWrite: 'admin',
+            text: 'LID',
+            prop: 'lid',
+            maxlen: 10,
         },
         LDAPdochazka: {
             name: 'LDAPdochazka',
@@ -566,7 +582,7 @@ define ([
         sEnick: {
             name: 'sEnick',
             aclProfileRead: null,
-            aclProfileWrite: 'admin',
+            aclProfileWrite: 'inactive',
             text: 'Nick',
             prop: 'searchKeyNick',
             maxlen: 20,
