@@ -63,26 +63,6 @@ define ([
 
     return function () {
 
-        test_desc = 'employee menu appears';
-        QUnit.test(test_desc, function (assert) {
-            console.log('***TEST*** ' + prefix + test_desc);
-            var done = assert.async(3);
-            login({"nam": "demo", "pwd": "demo"});
-            setTimeout(function () {
-                ct.login(assert, "demo", "passerby");
-                done();
-            }, 1000);
-            setTimeout(function () {
-                ct.mainMenuToMainEmpl(assert);
-                loggout();
-                done();
-            }, 2000);
-            setTimeout(function () {
-                ct.loggout(assert);
-                done();
-            }, 2500);
-        });
-
         test_desc = 'employee profile - passerby';
         QUnit.test(test_desc, function (assert) {
             var done = assert.async(4),
@@ -94,6 +74,7 @@ define ([
                 done();
             }, 1500);
             setTimeout(function () {
+                ct.mainMenu(assert);
                 // assert.ok(true, "Employee profile cache: " + QUnit.dump.parse(appCaches.profileCache));
                 assert.ok(appCaches.profileCacheLength() > 0, "Employee profile cache populated");
                 fullProfile = appCaches.getProfileByNick('demo');
@@ -103,9 +84,8 @@ define ([
                     "demo",
                     "Employee profile cache populated with employee \"demo\""
                 );
-                ct.mainMenuToMainEmpl(assert);
-                assert.ok(true, 'select 0 ("Profile") in mainEmpl as demo');
-                $('input[name="sel"]').val('0');
+                assert.ok(true, 'select 1 ("Profile") in mainMenu as demo');
+                $('input[name="sel"]').val('1');
                 $('input[name="sel"]').focus();
                 $('input[name="sel"]').trigger($.Event("keydown", {keyCode: 13}));
                 // no AJAX call is initiated, because the profile is already in the cache
@@ -131,21 +111,25 @@ define ([
         // contain only one object
         QUnit.test(test_desc, function (assert) {
             console.log('***TEST*** ' + prefix + test_desc);
-            var done = assert.async(4);
+            var done = assert.async(5);
             login({"nam": "root", "pwd": "immutable"});
             setTimeout(function () {
                 ct.login(assert, "root", "admin");
-                ct.mainMenuToMainEmpl(assert);
-                ct.mainEmplToSearchEmployee(assert);
+                done();
+            }, 1500);
+            setTimeout(function () {
+                ct.mainMenu(assert);
+                ct.mainMenuToMainAdmin(assert);
+                ct.mainAdminToSearchEmployee(assert);
                 // enter search term into form
                 $('#searchEmployee input[name="entry0"]').val('inactive');
                 // choose '0' to start search
-                $('input[name="sel"]').val('0');
+                $('input[name="sel"]').val('1');
                 $('input[name="sel"]').focus();
                 start.mmKeyListener($.Event("keydown", {keyCode: 13}));
-                assert.ok(true, "*** REACHED pressed 0 to initiate search for Dochazka employee inactive");
+                assert.ok(true, "*** REACHED pressed 1 to initiate search for Dochazka employee inactive");
                 done();
-            }, 1000);
+            }, 2000);
             setTimeout(function () {
                 var htmlbuf = $("#mainarea").html();
                 ct.stack(
@@ -174,18 +158,18 @@ define ([
                 );
                 ct.contains(
                     assert,
-                    $('#mainarea').html(),
-                    "#mainarea html",
-                    "0.&nbsp;LDAP sync",
+                    $('#minimenu').html(),
+                    "#minimenu html",
+                    ".&nbsp;LDAP&nbsp;sync",
                 );
-                assert.ok(true, "*** REACHED miniMenu contains 0. LDAP sync");
+                assert.ok(true, "*** REACHED miniMenu contains substring '. LDAP sync'");
                 // // choose '0' for ldapSync
                 // $('input[name="sel"]').val('0');
                 // $('input[name="sel"]').focus();
                 // start.mmKeyListener($.Event("keydown", {keyCode: 13}));
                 // assert.ok(true, "*** REACHED pressed 0 for LDAP sync");
                 done();
-            }, 2500);
+            }, 3000);
             setTimeout(function () {
                 // ct.contains(
                 //     assert,
@@ -224,7 +208,7 @@ define ([
                     2,
                     'After selecting X in ldapLookup',
                     'dmenu',
-                    'mainEmpl'
+                    'mainAdmin'
                 );
                 assert.ok(true, "*** REACHED mainEmpl dmenu via X from ldapLookup");
                 loggout();
